@@ -9,9 +9,9 @@ def enable_logging():
     logger.setLevel(logging.DEBUG)
     formatter = logging.Formatter('%(asctime)s | %(levelname)s | %(message)s', '%m-%d-%Y %H:%M:%S')
 
-    file_handler = logging.FileHandler('logs/debug.log')
-    file_handler.setLevel(logging.DEBUG)
-    file_handler.setFormatter(formatter)
+    # file_handler = logging.FileHandler('logs/debug.log')
+    # file_handler.setLevel(logging.DEBUG)
+    # file_handler.setFormatter(formatter)
 
     stream_handler = logging.StreamHandler()
     stream_handler.setLevel(logging.DEBUG)
